#
# spec file for package shim-leap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Move 'efi'-executables to '/usr/share/efi' (FATE#326960, bsc#1166523)
%define sysefibasedir  %{_datadir}/efi
%define sysefidir      %{sysefibasedir}/%{_target_cpu}
%if 0%{?suse_version} < 1600
# provide compatibility sym-link for residual kiwi, etc.
%define shim_lib64_share_compat 1
%endif

Name:           shim-leap
Version:        15.8
Release:        4.1
Summary:        UEFI shim loader
License:        BSD-2-Clause
Group:          System/Boot
Source0:        shim-15.8-lp155.8.2.x86_64.rpm
Source1:        shim-15.8-lp155.8.8.aarch64.rpm
Source2:        README
Source3:        shim-install
BuildRequires:  fde-tpm-helper-rpm-macros
BuildRequires:  update-bootloader-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64 aarch64

%description
does not exist

%package -n shim
Summary:        UEFI shim loader
Group:          System/Boot
Requires:       perl-Bootloader
%if 0%{?fde_tpm_update_requires:1}
%fde_tpm_update_requires
%endif

%description -n shim
shim is a trivial EFI application that, when run, attempts to open and
execute another application.

%prep
%ifarch         x86_64
rpm2cpio %{SOURCE0} | cpio --extract --unconditional --preserve-modification-time --make-directories
%else
rpm2cpio %{SOURCE1} | cpio --extract --unconditional --preserve-modification-time --make-directories
%endif

%build

%install
# purely repackaged
cp -a etc usr %{buildroot}
cp %{S:2} .

# Override shim-install
install -m 755 %{S:3} %{buildroot}/%{_sbindir}/shim-install

%if %{undefined shim_lib64_share_compat}
# Remove the sym-links in /usr/lib64/efi
rm -rf %{buildroot}/usr/lib64/efi
%endif

%post -n shim
%if 0%{?fde_tpm_update_post:1}
%fde_tpm_update_post shim
%endif

%if 0%{?update_bootloader_check_type_reinit_post:1}
%update_bootloader_check_type_reinit_post grub2-efi
%else
/sbin/update-bootloader --reinit || true
%endif

%posttrans -n shim
%{?update_bootloader_posttrans}
%{?fde_tpm_update_posttrans}

%files -n shim
%doc README
%dir %{?sysefibasedir}
%dir %{sysefidir}
%{sysefidir}/shim.efi
%{sysefidir}/shim-*.efi
%{sysefidir}/shim-*.der
%{sysefidir}/MokManager.efi
%{sysefidir}/fallback.efi
%if %{defined shim_lib64_share_compat}
# provide compatibility sym-link for previous kiwi, etc.
%dir /usr/lib64/efi
/usr/lib64/efi/*.efi
%endif
/etc/uefi
%{_sbindir}/shim-install
/usr/share/doc/packages/shim

%changelog
* Wed Feb 19 2025 Ana Guerrero <ana.guerrero@suse.com>
- Only copy uncompressed directories.
* Fri Sep 20 2024 Dominique Leuenberger <dleuenberger@suse.com>
- RelEng emergency fix: fix source number to install shim-install.
* Mon Sep  2 2024 Dennis Tseng <dennis.tseng@suse.com>
- Update shim version for aarch64 to shim-15.8-lp155.8.8.aarch64.rpm
  coming from openSUSE secure-boot 15.5
  + To avoid failure check by robot, SOURCEs in spec file are redefined.
  + Version: 15.8, "Jan 23 2024"
  + Include the bug fixes for bsc#1215099,bsc#1215098,bsc#1215100,bsc#1215101,
    bsc#1215102, and bsc#1215103.
* Tue Jul 23 2024 Dennis Tseng <dennis.tseng@suse.com>
- Update to shim to 15.8-shim-15.8-lp155.8.2.x86_64.rpm from
  openSUSE secure-boot 15.5
  + Version: 15.8, "Jan 23 2024"
  + Align the outside shim-install with the one in RPM file.
    This is because all important fixes in outside shim-install are
    also fixed in shim-install of RPM file. For consistency purposes,
    the outside shim-install is updated in this version.
  + Include the bug fixes for bsc#1215099,bsc#1215098,bsc#1215100,bsc#1215101,
    bsc#1215102, and bsc#1215103.
* Thu Mar 14 2024 Gary Ching-Pang Lin <glin@suse.com>
- Update shim-install to set the SRK algorithm for grub2 TPM2
  key protector (bsc#1213945)
  + 92d0f4305df73 Set the SRK algorithm for the TPM2 protector
- Build with update-bootloader-rpm-macros and
  fde-tpm-helper-rpm-macros and update the %%post and %%posttrans
  macros correctly
* Wed Jun  7 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update shim-install to support FDE
  + Read GRUB_CRYPTODISK_PASSWORD and GRUB_TPM2_SEALED_KEY to
    create the proper cryptomount command for grub.cfg
  + Save the PCR snapshot if grub2 supports the command
  + Support 'no_grub_install' to skip grub2-install
  + Detect the OS ID of openSUSE Leap
* Thu May 25 2023 Gary Ching-Pang Lin <glin@suse.com>
- Remove the sym-links in /usr/lib64/efi for the newer distro
  versions since we don't use them anymore
* Wed Jul 21 2021 jlee@suse.com
- Update to shim to 15.4-lp152.4.17.1 from openSUSE Leap 15.2
  + Version: 15.4, "Thu Jul 15 2021"
  + Updated openSUSE x86 signature
  + Include the fixes for bsc#1187696, bsc#1185261, bsc#1185441,
    bsc#1187071, bsc#1185621, bsc#1185261, bsc#1185232, bsc#1185261,
    bsc#1187260, bsc#1185232.
- Remove shim-install because the shim-install is updated in Leap
  15.2 RPM.
* Thu May 20 2021 Gary Ching-Pang Lin <glin@suse.com>
- shim-install: instead of assuming "removable" for Azure, remove
  fallback.efi from \EFI\Boot and copy grub.efi/cfg to \EFI\Boot
  to make \EFI\Boot bootable and keep the boot option created by
  efibootmgr (bsc#1185464, bsc#1185961)
* Fri May  7 2021 Gary Ching-Pang Lin <glin@suse.com>
- shim-install: always assume "removable" for Azure to avoid the
  endless reset loop (bsc#1185464)
* Tue Apr 27 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update to shim to 15.4-lp152.4.8.1 from openSUSE Leap 15.2 for
  SBAT support (bsc#1182057)
  + Version: 15.4, "Wed Apr 21 05:46:19 UTC 2021"
  + Include the fixes for bsc#1177789, CVE-2019-14584, bsc#1177315,
    bsc#1175509, bsc#1173411, bsc#1177404, bsc#1174512, bsc#1184454
- Add README to note why we need shim-leap for Tumbleweed
* Thu Aug 27 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update shim to 15+git47-lp152.4.5.1 from openSUSE Leap 15.2
  + shim-install: install MokManager to \EFI\boot to process the
    pending MOK request (bsc#1175626, bsc#1175656)
* Tue Aug 11 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update shim to 15+git47-lp152.4.3.1 from openSUSE Leap 15.2
  + Version: 15+git47 "Fri Jul 31 07:41:26 UTC 2020"
  + Use shim-install in the rpm package
* Wed Jul 22 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update the path to grub-tpm.efi in shim-install (bsc#1174320)
- shim-install: add check for btrfs is used as root file system to enable
  relative path lookup for file. (bsc#1153953)
- Update shim-install to handle the partitioned MD devices
  (bsc#1119762, bsc#1119763)
- Update grub2 path in shim-install
* Tue Mar 31 2020 Gary Ching-Pang Lin <glin@suse.com>
- Use the full path of efibootmgr to avoid errors when invoking
  shim-install from packagekitd (bsc#1168104)
* Mon Mar 30 2020 Gary Ching-Pang Lin <glin@suse.com>
- Use "suse_version" instead of "sle_version" to avoid
  shim_lib64_share_compat being set in Tumbleweed forever.
* Fri Mar 27 2020 Gary Ching-Pang Lin <glin@suse.com>
- Move 'efi'-executables to '/usr/share/efi'
  (FATE#326960, bsc#1166523)
* Thu Dec  6 2018 Gary Ching-Pang Lin <glin@suse.com>
- Update shim-install to set the grub2-install target explicitly
  for some special cases. (bsc#1118363)
* Fri Jun  8 2018 glin@suse.com
- Update shim to 14-lp150.8.5.1
  + Replace shim-bsc1092000-fallback-always-try-first-option.patch
    with shim-bsc1092000-fallback-menu.patch to show a countdown
    menu before reset (bsc#1092000)
* Mon May 14 2018 glin@suse.com
- Update shim to 14-lp150.7.3
  + Amend fallback.efi to avoid being trapped in the infinite reset
    loop (bsc#1092000)
* Wed Apr 25 2018 mlin@suse.com
- Update shim to 14-lp150.4.1
- New signature from Microsoft
* Tue Apr 25 2017 glin@suse.com
- Update shim to 0.9-15.3.1
  + shim-install: add option --suse-enable-tpm (fate#315831)
    (Fix from mchang@suse.com)
* Tue Dec 27 2016 glin@suse.com
- Update shim to 0.9-13.1
  + Update shim-install to support "--no-nvram" and improve
    removable media and fallback mode handling (bsc#985568,
    bsc#999818) (Fix from mchang@suse.com)
* Fri Oct  7 2016 jsegitz@novell.com
- New signature from Microsoft
* Fri Aug 19 2016 mchang@suse.com
- shim-install : fix regression of password prompt (bsc#993764)
* Fri Aug  5 2016 glin@suse.com
- Add shim-bsc991885-fix-sig-length.patch to fix the signature
  length passed to Authenticode (bsc#991885)
* Wed Aug  3 2016 glin@suse.com
- Update shim-bsc973496-mokmanager-no-append-write.patch to try
  append write first
* Tue Aug  2 2016 glin@suse.com
- Add shim-update-openssl-1.0.2h.patch to update openssl to 1.0.2h
- Bump the requirement of gnu-efi due to the HTTPBoot support
* Mon Aug  1 2016 glin@suse.com
- Add shim-httpboot-support.patch to support HTTPBoot
- Add shim-update-openssl-1.0.2g.patch to update openssl to 1.0.2g
  and Cryptlib to 5e2318dd37a51948aaf845c7d920b11f47cdcfe6
- Drop patches since they are merged into
  shim-update-openssl-1.0.2g.patch
  + shim-update-openssl-1.0.2d.patch
  + shim-gcc5.patch
  + shim-bsc950569-fix-cryptlib-va-functions.patch
  + shim-fix-aarch64.patch
- Refresh shim-change-debug-file-path.patch
- Add shim-bsc973496-mokmanager-no-append-write.patch to work
  around the firmware that doesn't support APPEND_WRITE (bsc973496)
- shim-install : remove '\n' from the help message (bsc#991188)
- shim-install : print a message if there is no valid EFI partition
  (bsc#991187)
* Mon May  9 2016 rw@suse.com
- shim-install : support simple MD RAID1 target devices (FATE#314829)
* Wed May  4 2016 agraf@suse.com
- Add shim-fix-aarch64.patch to fix compilation on AArch64 (bsc#978438)
* Wed Mar  9 2016 mchang@suse.com
- shim-install : fix typing ESC can escape to parent config which is
  in command mode and cannot return back (bsc#966701)
- shim-install : fix no which command for JeOS (bsc#968264)
* Thu Dec  3 2015 jsegitz@novell.com
- acquired updated signature from Microsoft
* Mon Nov  9 2015 glin@suse.com
- Add shim-bsc950569-fix-cryptlib-va-functions.patch to fix the
  definition of va functions to avoid the potential crash
  (bsc#950569)
- Update shim-opensuse-cert-prompt.patch to avoid setting NULL to
  MokListRT (bsc#950801)
- Drop shim-fix-mokmanager-sections.patch as we are using the
  newer binutils now
- Refresh shim-change-debug-file-path.patch
* Thu Oct  8 2015 jsegitz@novell.com
- acquired updated signature from Microsoft
* Tue Sep 15 2015 mchang@suse.com
- shim-install : set default GRUB_DISTRIBUTOR from /etc/os-release
  if it is empty or not set by user (bsc#942519)
* Thu Jul 16 2015 glin@suse.com
- Add shim-update-openssl-1.0.2d.patch to update openssl to 1.0.2d
- Refresh shim-gcc5.patch and add it back since we really need it
- Add shim-change-debug-file-path.patch to change the debug file
  path in shim.efi
  + also add the debuginfo and debugsource subpackages
- Drop shim-fix-gnu-efi-30w.patch which is not necessary anymore
* Mon Jul  6 2015 glin@suse.com
- Update to 0.9
- Refresh patches
  + shim-fix-gnu-efi-30w.patch
  + shim-fix-mokmanager-sections.patch
  + shim-opensuse-cert-prompt.patch
- Drop upstreamed patches
  + shim-bsc920515-fix-fallback-buffer-length.patch
  + shim-mokx-support.patch
  + shim-update-cryptlib.patch
- Drop shim-bsc919675-uninstall-shim-protocols.patch since
  upstream fixed the bug in another way.
- Drop shim-gcc5.patch which was fixed in another way
* Wed Apr  8 2015 glin@suse.com
- Fix tags in the spec file
* Tue Apr  7 2015 glin@suse.com
- Add shim-update-cryptlib.patch to update Cryptlib to r16559 and
  openssl to 0.9.8zf
- Add shim-bsc919675-uninstall-shim-protocols.patch to uninstall
  the shim protocols at Exit (bsc#919675)
- Add shim-bsc920515-fix-fallback-buffer-length.patch to adjust
  the buffer size for the boot options (bsc#920515)
- Refresh shim-opensuse-cert-prompt.patch
* Thu Apr  2 2015 crrodriguez@opensuse.org
- shim-gcc5.patch: shim needs -std=gnu89 to build with GCC5
* Tue Feb 17 2015 mchang@suse.com
- shim-install : fix cryptodisk installation (boo#917427)
* Tue Nov 11 2014 glin@suse.com
- Add shim-fix-mokmanager-sections.patch to fix the objcopy
  parameters for the EFI files
* Tue Oct 28 2014 glin@suse.com
- Update to 0.8
- Add shim-fix-gnu-efi-30w.patch to adapt the change in
  gnu-efi-3.0w
- Merge shim-signed-unsigned-compares.patch,
  shim-mokmanager-support-sha-family.patch and
  shim-bnc863205-mokmanager-fix-hash-delete.patch into
  shim-mokx-support.patch
- Refresh shim-opensuse-cert-prompt.patch
- Drop upstreamed patches: shim-update-openssl-0.9.8zb.patch,
  bug-889332_shim-overflow.patch, and bug-889332_shim-mok-oob.patch
- Enable aarch64
* Mon Oct 13 2014 jsegitz@novell.com
- Fixed buffer overflow and OOB access in shim trusted code path
  (bnc#889332, CVE-2014-3675, CVE-2014-3676, CVE-2014-3677)
  * added bug-889332_shim-mok-oob.patch, bug-889332_shim-overflow.patch
- Added new certificate by Microsoft
* Wed Sep  3 2014 lnussel@suse.de
- re-introduce build failure if shim_enforce_ms_signature is defined. That way
  a project like openSUSE:Factory can decide whether or not shim needs a valid
  MS signature.
* Tue Aug 19 2014 glin@suse.com
- Add shim-update-openssl-0.9.8zb.patch to update openssl to
  0.9.8zb
* Tue Aug 12 2014 jsegitz@suse.com
- updated shim to new version (OpenSSL 0.9.8za) and requested a new
  certificate from Microsoft. Removed
  * shim-allow-fallback-use-system-loadimage.patch
  * shim-bnc872503-check-key-encoding.patch
  * shim-bnc877003-fetch-from-the-same-device.patch
  * shim-correct-user_insecure-usage.patch
  * shim-fallback-avoid-duplicate-bootorder.patch
  * shim-fallback-improve-entries-creation.patch
  * shim-fix-dhcpv4-path-generation.patch
  * shim-fix-uninitialized-variable.patch
  * shim-fix-verify-mok.patch
  * shim-get-variable-check.patch
  * shim-improve-error-messages.patch
  * shim-mokmanager-delete-bs-var-right.patch
  * shim-mokmanager-handle-keystroke-error.patch
  * shim-remove-unused-variables.patch
  since they're included in upstream and rebased the remaining onces.
  Added shim-signed-unsigned-compares.patch to fix some compiler
  warnings
* Tue Aug 12 2014 glin@suse.com
- Keep shim-devel.efi for the devel project
* Fri Aug  8 2014 lnussel@suse.de
- don't fail the build if the UEFI signing service signature can't
  be attached anymore. This way shim can still pass through staging
  projects. We will verify the correct signature for release builds
  using openQA instead.
* Mon Aug  4 2014 mchang@suse.com
- shim-install: fix GRUB shows broken letters at boot by calling
  grub2-install to initialize /boot/grub2 directory with files
  needed by grub.cfg (bnc#889765)
* Wed May 28 2014 glin@suse.com
- Add shim-remove-unused-variables.patch to remove the unused
  variables
- Add shim-bnc872503-check-key-encoding.patch to check the encoding
  of the keys (bnc#872503)
- Add shim-bnc877003-fetch-from-the-same-device.patch to fetch the
  netboot image from the same device (bnc#877003)
- Refresh shim-opensuse-cert-prompt.patch
* Wed May 14 2014 glin@suse.com
- Use --reinit instead of --refresh in %%post to update the files
  in /boot
* Tue Apr 29 2014 mchang@suse.com
- shim-install: fix boot partition and rollback support kluge
  (bnc#875385)
* Thu Apr 10 2014 glin@suse.com
- Replace shim-mokmanager-support-sha1.patch with
  shim-mokmanager-support-sha-family.patch to support the SHA
  family
* Mon Apr  7 2014 glin@suse.com
- Add shim-mokmanager-support-sha1.patch to support SHA1 hashes in
  MOK
* Mon Mar 31 2014 mchang@suse.com
- snapper rollback support (fate#317062)
  - refresh shim-install
* Thu Mar 13 2014 glin@suse.com
- Insert the right signature (bnc#867974)
* Mon Mar 10 2014 glin@suse.com
- Add shim-fix-uninitialized-variable.patch to fix the use of
  uninitialzed variables in lib
* Fri Mar  7 2014 glin@suse.com
- Add shim-mokmanager-delete-bs-var-right.patch to delete the BS+NV
  variables the right way
- Update shim-opensuse-cert-prompt.patch to delete openSUSE_Verify
  correctly
* Thu Mar  6 2014 glin@suse.com
- Add shim-fallback-avoid-duplicate-bootorder.patch to fix the
  duplicate entries in BootOrder
- Add shim-allow-fallback-use-system-loadimage.patch to handle the
  shim protocol properly to keep only one protocol entity
- Refresh shim-opensuse-cert-prompt.patch
* Thu Mar  6 2014 mchang@suse.com
- shim-install: fix the $prefix to use grub2-mkrelpath for paths
  on btrfs subvolume (bnc#866690).
* Tue Mar  4 2014 glin@suse.com
- FATE#315002: Update shim-install to install shim.efi as the EFI
  default bootloader when none exists in \EFI\boot.
* Thu Feb 27 2014 fcrozat@suse.com
- Update signature-sles.asc: shim signed by UEFI signing service,
  based on code from "Thu Feb 20 11:57:01 UTC 2014"
* Fri Feb 21 2014 glin@suse.com
- Add shim-opensuse-cert-prompt.patch to show the prompt to ask
  whether the user trusts the openSUSE certificate or not
* Thu Feb 20 2014 lnussel@suse.de
- allow package to carry multiple signatures
- check correct certificate is embedded
* Thu Feb 20 2014 lnussel@suse.de
- always clean up generated files that embed certificates
  (shim_cert.h shim.cer shim.crt) to make sure next build loop
  rebuilds them properly
* Mon Feb 17 2014 glin@suse.com
- Add shim-bnc863205-mokmanager-fix-hash-delete.patch to fix the
  hash deletion operation to avoid ruining the whole list
  (bnc#863205)
* Tue Feb 11 2014 glin@suse.com
- Update shim-mokx-support.patch to support the resetting of MOK
  blacklist
- Add shim-get-variable-check.patch to fix the variable checking
  in get_variable_attr
- Add shim-fallback-improve-entries-creation.patch to improve the
  boot entry pathes and avoid generating the boot entries that
  are already there
- Update SUSE certificate
- Update attach_signature.sh, show_hash.sh, strip_signature.sh,
  extract_signature.sh and show_signatures.sh to remove the
  creation of the temporary nss database
- Add shim-only-os-name.patch: remove the kernel version of the
  build server
- Match the the prefix of the project name properly by escaping the
  percent sign.
* Wed Jan 22 2014 lnussel@suse.de
- enable signature assertion also in SUSE: hierarchy
* Fri Dec  6 2013 glin@suse.com
- Add shim-mokmanager-handle-keystroke-error.patch to handle the
  error status from ReadKeyStroke to avoid unexpected keys
* Thu Dec  5 2013 glin@suse.com
- Update to 0.7
- Add upstream patches:
  + shim-fix-verify-mok.patch
  + shim-improve-error-messages.patch
  + shim-correct-user_insecure-usage.patch
  + shim-fix-dhcpv4-path-generation.patch
- Add shim-mokx-support.patch to support the MOK blacklist
  (Fate#316531)
- Drop upstreamed patches
  + shim-fix-pointer-casting.patch
  + shim-merge-lf-loader-code.patch
  + shim-fix-simple-file-selector.patch
  + shim-mokmanager-support-crypt-hash-method.patch
  + shim-bnc804631-fix-broken-bootpath.patch
  + shim-bnc798043-no-doulbe-separators.patch
  + shim-bnc807760-change-pxe-2nd-loader-name.patch
  + shim-bnc808106-correct-certcount.patch
  + shim-mokmanager-ui-revamp.patch
  + shim-netboot-fixes.patch
  + shim-mokmanager-disable-gfx-console.patch
- Drop shim-suse-build.patch: it's not necessary anymore
- Drop shim-bnc841426-silence-shim-protocols.patch: shim is not
  verbose by default
* Thu Oct 31 2013 fcrozat@suse.com
- Update microsoft.asc: shim signed by UEFI signing service, based
  on code from "Tue Oct  1 04:29:29 UTC 2013".
* Tue Oct  1 2013 glin@suse.com
- Add shim-netboot-fixes.patch to include upstream netboot fixes
- Add shim-mokmanager-disable-gfx-console.patch to disable the
  graphics console to avoid system hang on some machines
- Add shim-bnc841426-silence-shim-protocols.patch to silence the
  shim protocols (bnc#841426)
* Wed Sep 25 2013 glin@suse.com
- Create boot.csv in ESP for fallback.efi to restore the boot entry
* Tue Sep 17 2013 fcrozat@suse.com
- Update microsoft.asc: shim signed by UEFI signing service, based
  on code from "Fri Sep  6 13:57:36 UTC 2013".
- Improve extract_signature.sh to work on current path.
* Fri Sep  6 2013 lnussel@suse.de
- set timestamp of PE file to time of the binary the signature was
  made for.
- make sure cert.o get's rebuilt for each target
* Fri Sep  6 2013 fcrozat@suse.com
- Update microsoft.asc: shim signed by UEFI signing service, based
  on code from "Wed Aug 28 15:54:38 UTC 2013"
* Wed Aug 28 2013 lnussel@suse.de
- always build a shim that embeds the distro's certificate (e.g.
  shim-opensuse.efi). If the package is built in the devel project
  additionally shim-devel.efi is created. That allows us to either
  load grub2/kernel signed by the distro or signed by the devel
  project, depending on use case. Also shim-$distro.efi from the
  devel project can be used to request additional signatures.
* Wed Aug 28 2013 lnussel@suse.de
- also include old openSUSE 4096 bit certificate to be able to still
  boot kernels signed with that key.
- add show_signatures script
* Tue Aug 27 2013 lnussel@suse.de
- replace the 4096 bit openSUSE UEFI CA certificate with new a
  standard compliant 2048 bit one.
* Tue Aug 20 2013 lnussel@suse.de
- fix shell syntax error
* Wed Aug  7 2013 lnussel@suse.de
- don't include binary in the sources. Instead package the raw
  signature and attach it during build (bnc#813448).
* Tue Jul 30 2013 glin@suse.com
- Update shim-mokmanager-ui-revamp.patch to include fixes for
  MokManager
  + reboot the system after clearing MOK password
  + fetch more info from X509 name
  + check the suffix of the key file
* Tue Jul 23 2013 glin@suse.com
- Update to 0.4
- Rebase patches
  + shim-suse-build.patch
  + shim-mokmanager-support-crypt-hash-method.patch
  + shim-bnc804631-fix-broken-bootpath.patch
  + shim-bnc798043-no-doulbe-separators.patch
  + shim-bnc807760-change-pxe-2nd-loader-name.patch
  + shim-bnc808106-correct-certcount.patch
  + shim-mokmanager-ui-revamp.patch
- Add patches
  + shim-merge-lf-loader-code.patch: merge the Linux Foundation
    loader UI code
  + shim-fix-pointer-casting.patch: fix a casting issue and the
    size of an empty vendor cert
  + shim-fix-simple-file-selector.patch: fix the buffer allocation
    in the simple file selector
- Remove upstreamed patches
  + shim-support-mok-delete.patch
  + shim-reboot-after-changes.patch
  + shim-clear-queued-key.patch
  + shim-local-key-sign-mokmanager.patch
  + shim-get-2nd-stage-loader.patch
  + shim-fix-loadoptions.patch
- Remove unused patch: shim-mokmanager-new-pw-hash.patch and
  shim-keep-unsigned-mokmanager.patch
- Install the vendor certificate to /etc/uefi/certs
* Wed May  8 2013 glin@suse.com
- Add shim-mokmanager-ui-revamp.patch to update the MokManager UI
* Wed Apr  3 2013 glin@suse.com
- Call update-bootloader in %%post to update *.efi in \efi\opensuse
  (bnc#813079)
* Fri Mar  8 2013 glin@suse.com
- Add shim-bnc807760-change-pxe-2nd-loader-name.patch to change the
  PXE 2nd stage loader name (bnc#807760)
- Add shim-bnc808106-correct-certcount.patch to correct the
  certificate count of the signature list (bnc#808106)
* Fri Mar  1 2013 glin@suse.com
- Add shim-bnc798043-no-doulbe-separators.patch to remove double
  seperators from the bootpath (bnc#798043#c4)
* Thu Feb 28 2013 lnussel@suse.de
- sign shim also with openSUSE certificate
* Wed Feb 27 2013 mls@suse.de
- identify project, export certificate as DER file
- don't create an unused extra keypair
* Thu Feb 21 2013 glin@suse.com
- Add shim-bnc804631-fix-broken-bootpath.patch to fix the broken
  bootpath generated in generate_path(). (bnc#804631)
* Mon Feb 11 2013 fcrozat@suse.com
- Update with shim signed by UEFI signing service, based on code
  from "Thu Feb  7 06:56:19 UTC 2013".
* Thu Feb  7 2013 lnussel@suse.de
- prepare for having a signed shim from the UEFI signing service
* Thu Feb  7 2013 glin@suse.com
- Sign shim-opensuse.efi and MokManager.efi with the openSUSE cert
- Add shim-keep-unsigned-mokmanager.patch to keep the unsigned
  MokManager and sign it later.
* Wed Feb  6 2013 mchang@suse.com
- Add shim-install utility
- Add Recommends to grub2-efi
* Wed Jan 30 2013 glin@suse.com
- Add shim-mokmanager-support-crypt-hash-method.patch to support
  password hash from /etc/shadow (FATE#314506)
* Tue Jan 29 2013 glin@suse.com
- Embed openSUSE-UEFI-CA-Certificate.crt in shim
- Rename shim-unsigned.efi to shim-opensuse.efi.
* Fri Jan 18 2013 glin@suse.com
- Update shim-mokmanager-new-pw-hash.patch to extend the password
  hash format
- Rename shim.efi as shim-unsigned.efi
* Wed Jan 16 2013 glin@suse.com
- Merge patches for FATE#314506
  + Add shim-support-mok-delete.patch to add support for deleting
    specific keys
  + Add shim-mokmanager-new-pw-hash.patch to support the new
    password hash.
- Drop shim-correct-mok-size.patch which is included in
  shim-support-mok-delete.patch
- Merge shim-remove-debug-code.patch and
  shim-local-sign-mokmanager.patch into
  shim-local-key-sign-mokmanager.patch
- Install COPYRIGHT
* Tue Jan 15 2013 glin@suse.com
- Add shim-fix-loadoptions.patch to adopt the UEFI shell style
  LoadOptions (bnc#798043)
- Drop shim-check-pk-kek.patch since upstream rejected the patch
  due to violation of SPEC.
- Install EFI binaries to /usr/lib64/efi
* Wed Dec 26 2012 glin@suse.com
- Update shim-reboot-after-changes.patch to avoid rebooting the
  system after enrolling keys/hashes from the file system
- Add shim-correct-mok-size.patch to correct the size of MOK
- Add shim-clear-queued-key.patch to clear the queued key and show
  the menu properly
* Wed Dec 12 2012 fcrozat@suse.com
- Remove shim-rpmlintrc, it wasn't fixing the error, hide error
  stdout to prevent post build check to get triggered by cast
  warnings in openSSL code
- Add shim-remove-debug-code.patch: remove debug code
* Wed Dec 12 2012 glin@suse.com
- Add shim-rpmlintrc to filter 64bit portability errors
* Tue Dec 11 2012 glin@suse.com
- Add shim-local-sign-mokmanager.patch to create a local certicate
  to sign MokManager
- Add shim-get-2nd-stage-loader.patch to get the second stage
  loader path from the load options
- Add shim-check-pk-kek.patch to verify EFI images with PK and KEK
- Add shim-reboot-after-changes.patch to reboot the system after
  enrolling or erasing keys
- Install the EFI images to /usr/lib64/shim instead of the EFI
  partition
- Update the mail address of the author
* Fri Nov  2 2012 glin@suse.com
- Add new package shim 0.2 (FATE#314484)
  + It's in fact git 2fd180a92 since there is no tag for 0.2
